import{_ as p}from"./Login.vue_vue_type_script_setup_true_lang-CjaOjKLT.js";import{e as d,f as i,v as u,p as n,ag as f,ak as m,g as l,aO as _}from"./jwt-decode.esm-CW-ehmUm.js";import{u as b}from"./workspaceStore-DcnxpW_c.js";import"./OTPInput-CIVvtVfG.js";import"./Logo-D7ItGdyg.js";import"./string-DG69OOx2.js";import"./CircularLoading-ylUWWooD.js";import"./index-DzVyDbXC.js";import"./userStore-C91zXrXx.js";import"./runnerData-B-rwjNHa.js";import"./url-AFSWCooG.js";import"./colorHelpers-9BBJQtv0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="b2b7c6f0-107d-4b7c-9696-a9d288f6370f",e._sentryDebugIdIdentifier="sentry-dbid-b2b7c6f0-107d-4b7c-9696-a9d288f6370f")}catch{}})();const g={class:"runner"},y=d({__name:"Login",setup(e){const o=f(),r=m(),t=b(),c=async()=>{const{redirect:a,...s}=r.query;if(a){await o.push({path:a,query:s,params:r.params});return}o.push({name:"playerHome",query:s})};return(a,s)=>(l(),i("div",g,[u(p,{"logo-url":n(t).state.workspace?.logoUrl??void 0,"brand-name":n(t).state.workspace?.brandName,locale:n(t).state.workspace?.language??"en",onDone:c},null,8,["logo-url","brand-name","locale"])]))}}),R=_(y,[["__scopeId","data-v-12c690e1"]]);export{R as default};
//# sourceMappingURL=Login-qhXP23OY.js.map
