import{C as t,_ as p}from"./View.vue_vue_type_script_setup_true_lang-Colj6Hti.js";import{e as i,n,g as s,p as m}from"./jwt-decode.esm-CW-ehmUm.js";import{u as a}from"./projectStore-BxyV_vxa.js";import"./router-BiZH2muW.js";import"./ts.worker-BACR3sLa.js";import"./fetch-CQKoK3mD.js";import"./tables-BzgKolvU.js";import"./string-DG69OOx2.js";import"./SaveButton-BduB2ro0.js";import"./ExclamationCircleOutlined-CoO_M75i.js";import"./CrudView-BPlJKDdI.js";import"./DocsButton.vue_vue_type_script_setup_true_lang-D_4CoWr0.js";import"./constants-N9y8G168.js";import"./url-AFSWCooG.js";import"./PhDotsThreeVertical.vue-BpNbKi1q.js";import"./index-B1woDf_H.js";import"./asyncComputed-Xa1P0TNG.js";import"./PhPencil.vue-HlAVRhGs.js";import"./useCodebaseEvents-B6ucGy-u.js";import"./contracts.generated-Dd1L4e6U.js";import"./index-DzVyDbXC.js";import"./project-Fo2FlwgA.js";import"./organizationSwitcher-aqSMDQQ_.js";import"./organization-j66jOtof.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="e63de636-dc26-4a41-b8e6-90eb721b24db",o._sentryDebugIdIdentifier="sentry-dbid-e63de636-dc26-4a41-b8e6-90eb721b24db")}catch{}})();const z=i({__name:"EnvVars",setup(o){const r=a(),e=new t(r.projectId);return(d,c)=>(s(),n(p,{"env-var-repository":m(e),mode:"console"},null,8,["env-var-repository"]))}});export{z as default};
//# sourceMappingURL=EnvVars-BBtviWc4.js.map
