import{_ as d}from"./NewEditor-BFL1DSvk.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[s]="98e63b21-d307-4ec4-b6c5-47f0cd05cd8d",t._sentryDebugIdIdentifier="sentry-dbid-98e63b21-d307-4ec4-b6c5-47f0cd05cd8d")}catch{}})();var e,n=(e=class{constructor(s){this.init=s,this.records=this.init()}reset(){this.records=this.init()}},d(e,"ImperativeState"),e);export{n as I};
//# sourceMappingURL=chunk-QZHKN3VN-BQj8OH7r.js.map
