import{e as d,b as s,f as l,g as i,k as r,h as c,I as f,H as a,aO as u}from"./jwt-decode.esm-CW-ehmUm.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="7371567f-3a03-4216-a2fc-4442a9c63bda",e._sentryDebugIdIdentifier="sentry-dbid-7371567f-3a03-4216-a2fc-4442a9c63bda")}catch{}})();const y=d({__name:"ContentLayout",props:{fullWidth:{type:Boolean},noPadding:{type:Boolean},flexLayout:{type:Boolean},innerPadding:{}},setup(e){const n=e,t=s(()=>({...n.innerPadding&&{padding:n.innerPadding}}));return(o,g)=>(i(),l("div",{class:a(["content-layout",{"no-padding":e.noPadding}])},[r("div",{class:a(["centered-layout",{"full-width":e.fullWidth,"flex-layout":e.flexLayout}]),style:f(t.value)},[c(o.$slots,"default",{},void 0,!0)],6)],2))}}),b=u(y,[["__scopeId","data-v-00e066e8"]]);export{b as C};
//# sourceMappingURL=ContentLayout-BkBXWftn.js.map
