import{L as f}from"./CircularLoading-ylUWWooD.js";import{e as u,ak as p,Q as _,f as h,g as l,k as c,v as g,aO as m}from"./jwt-decode.esm-CW-ehmUm.js";import{E as r,a as y}from"./router-BiZH2muW.js";import"./ts.worker-BACR3sLa.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="fa516f61-3190-4b59-8106-255f0a1a552d",e._sentryDebugIdIdentifier="sentry-dbid-fa516f61-3190-4b59-8106-255f0a1a552d")}catch{}})();const w={class:"authorize"},b={class:"content"},A=u({__name:"Authorize",setup(e){const o=p();return _(()=>{const{client_id:a,redirect_uri:s,response_type:n,state:i}=o.query,t=r.cloudApi.startsWith("https://")||r.cloudApi.startsWith("http://")?new URL(`${r.cloudApi}/oauth/authorize`):new URL(`${location.origin}${r.cloudApi}/oauth/authorize`);typeof a=="string"&&t.searchParams.set("client_id",a),typeof s=="string"&&t.searchParams.set("redirect_uri",s),typeof n=="string"&&t.searchParams.set("response_type",n),typeof i=="string"&&t.searchParams.set("state",i);const d=y.getAuthor();d?.jwt&&t.searchParams.set("session_token",d.jwt),window.location.href=t.toString()}),(a,s)=>(l(),h("div",w,[c("div",b,[s[0]||(s[0]=c("h1",null,"Authorizing...",-1)),g(f)])]))}}),L=m(A,[["__scopeId","data-v-57fe5408"]]);export{L as default};
//# sourceMappingURL=Authorize-CvxpniHO.js.map
