import{_ as a}from"./logo-BiWG9_W5.js";import{L as r}from"./Logo-D7ItGdyg.js";import{e as d,n as o,p as s,g as i}from"./jwt-decode.esm-CW-ehmUm.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="e145dd41-0093-4a15-98d3-82458badb89a",e._sentryDebugIdIdentifier="sentry-dbid-e145dd41-0093-4a15-98d3-82458badb89a")}catch{}})();const b=d({__name:"AbstraLogo",props:{hideText:{type:Boolean},size:{}},setup(e){return(t,n)=>(i(),o(r,{"image-url":s(a),"brand-name":"Abstra","hide-text":e.hideText,size:e.size??"small"},null,8,["image-url","hide-text","size"]))}});export{b as _};
//# sourceMappingURL=AbstraLogo.vue_vue_type_script_setup_true_lang-DC7KcZiO.js.map
