import{B as f}from"./BaseLayout-BpyOEuFK.js";import{C as l}from"./ContentLayout-BkBXWftn.js";import{e as p,ak as _,b as i,F as g,a4 as b,n as r,g as s,w as m,v as y,j as w}from"./jwt-decode.esm-CW-ehmUm.js";import{_ as v}from"./BillingAlert.vue_vue_type_script_setup_true_lang-C2wmoD8n.js";import{u as z}from"./projectsStore-D--EEngC.js";import"./router-BiZH2muW.js";import"./ts.worker-BACR3sLa.js";import"./index-DzVyDbXC.js";import"./member-LVOrKo62.js";import"./organization-j66jOtof.js";import"./project-Fo2FlwgA.js";import"./tables-BzgKolvU.js";import"./string-DG69OOx2.js";import"./cascaderStore-B7NHg5Vp.js";import"./organizationSwitcher-aqSMDQQ_.js";import"./ant-design-BUwJj5_F.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="f4efdf8e-4715-4c0f-9465-b5604d0e080b",t._sentryDebugIdIdentifier="sentry-dbid-f4efdf8e-4715-4c0f-9465-b5604d0e080b")}catch{}})();const P=p({__name:"Organization",setup(t){const e=_(),o=z(),n=i(()=>e.params.organizationId);g(n,a=>{a&&o.fetchedState?.organization?.id!==a&&o.fetchState(a)},{immediate:!0});const u=i(()=>o.fetchedState?.organization),d=i(()=>u.value?.billingMetadata);return(a,h)=>{const c=b("RouterView");return s(),r(f,null,{content:m(()=>[y(l,null,{default:m(()=>[d.value?(s(),r(v,{key:0,"billing-metadata":d.value,"organization-id":n.value},null,8,["billing-metadata","organization-id"])):w("",!0),(s(),r(c,{key:n.value}))]),_:1})]),_:1})}}});export{P as default};
//# sourceMappingURL=Organization-BSym4o9S.js.map
