import{N as c}from"./Navbar-BBjdYl3m.js";import{e as d,ak as u,b as a,l,a4 as f,f as _,g as b,v as p,k as y,aO as I}from"./jwt-decode.esm-CW-ehmUm.js";import"./logo-BiWG9_W5.js";import"./AbstraButton.vue_vue_type_script_setup_true_lang-CNvpUmrq.js";import"./constants-N9y8G168.js";import"./PhCaretDown.vue-BijGLAR5.js";import"./PhPencilSimple.vue-D-xFoaXk.js";import"./router-BiZH2muW.js";import"./ts.worker-BACR3sLa.js";import"./organization-j66jOtof.js";import"./tables-BzgKolvU.js";import"./string-DG69OOx2.js";import"./keyboard-Bl7sW6_S.js";import"./os-C7n0f_2A.js";import"./projectStore-BxyV_vxa.js";import"./project-Fo2FlwgA.js";import"./organizationSwitcher-aqSMDQQ_.js";import"./cascaderStore-B7NHg5Vp.js";import"./CreateProjectModal.vue_vue_type_script_setup_true_lang-Tq2kOpOR.js";import"./member-LVOrKo62.js";import"./index-D-djuDvn.js";import"./index-Dg2ckLRl.js";import"./CreateTableModal.vue_vue_type_script_setup_true_lang-Cu4XSsnn.js";import"./PhNotePencil.vue-D10k9A5J.js";import"./PhSignOut.vue-Brr5lDmU.js";import"./index-B1woDf_H.js";import"./index-DiRvaywT.js";import"./PhPlus.vue-DArvEh_N.js";import"./omniChatStore-Dalui0bJ.js";import"./files-C-s7ZNO6.js";import"./contracts.generated-Dd1L4e6U.js";import"./runnerData-B-rwjNHa.js";import"./url-AFSWCooG.js";import"./colorHelpers-9BBJQtv0.js";import"./uuid-Cebg661w.js";import"./useLintersStore-BoB4T_3g.js";import"./PhCopySimple.vue-HGCfL-Oc.js";import"./PhSparkle.vue-D9XJeVm-.js";import"./index-BjGIyQpu.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[o]="23fd9fc5-154e-498a-bbf1-0fc95511e3c1",r._sentryDebugIdIdentifier="sentry-dbid-23fd9fc5-154e-498a-bbf1-0fc95511e3c1")}catch{}})();const v={class:"console-layout"},g={class:"console-content"},w=d({__name:"ConsoleLayout",setup(r){const o=u(),s=a(()=>!!o.params.projectId),n=a(()=>{const t=o.meta.pageNameKey;if(t)return t.startsWith("i18n_")?l.translateIfFound(t,null):t}),m=a(()=>{const t=o.params.projectId,i=o.params.tableId,e=o.params.organizationId;if(t)return{projectId:t,tableId:i,currentPageName:n.value};if(e)return{organizationId:e}});return(t,i)=>{const e=f("RouterView");return b(),_("div",v,[p(c,{"use-cascader":!0,"cascader-props":m.value,"show-ai-sparkles":s.value},null,8,["cascader-props","show-ai-sparkles"]),y("div",g,[p(e)])])}}}),po=I(w,[["__scopeId","data-v-62f8634d"]]);export{po as default};
//# sourceMappingURL=ConsoleLayout-Dxx37dk0.js.map
