import{P as g}from"./PlayerNavbar-WY8fapOA.js";import{e as _,ak as i,r as h,b,f as k,n as y,j as w,k as v,p as a,v as L,a4 as C,ag as I,g as c,aO as N}from"./jwt-decode.esm-CW-ehmUm.js";import{u as V}from"./workspaceStore-DcnxpW_c.js";import"./userStore-C91zXrXx.js";import"./metadata-Cfx0fjM3.js";import"./PhCursorClick.vue-KsF_VmxQ.js";import"./PhHouse.vue-CsA_UCyD.js";import"./PhMagnifyingGlass.vue-CedOSv9d.js";import"./PhWebhooksLogo.vue-BILteujJ.js";import"./LoadingOutlined-CAW-snM0.js";import"./PhSignOut.vue-Brr5lDmU.js";import"./index-DiRvaywT.js";import"./runnerData-B-rwjNHa.js";import"./url-AFSWCooG.js";import"./colorHelpers-9BBJQtv0.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="833b752a-2fb5-4971-8d55-c6bcbeaa4f89",o._sentryDebugIdIdentifier="sentry-dbid-833b752a-2fb5-4971-8d55-c6bcbeaa4f89")}catch{}})();const B={class:"main-container"},D={class:"content"},P=_({__name:"Main",setup(o){const e=I(),t=V(),p=i().path,n=h(null),d=async({path:r,id:s})=>{n.value=s,await e.push({path:`/${r}`}),n.value=null},u=()=>{e.push({name:"playerLogin"})},l=()=>{e.push({name:"playerLogin"})},m=b(()=>!!i().meta.hideLogin);return(r,s)=>{const f=C("RouterView");return c(),k("div",B,[a(t).state.workspace?(c(),y(g,{key:0,"current-path":a(p),"hide-login":m.value,"runner-data":a(t).state.workspace,loading:n.value,"show-sidebar":a(t).state.currentPageType==="form",onNavigate:d,onLoginClick:l,onLogoutClick:u},null,8,["current-path","hide-login","runner-data","loading","show-sidebar"])):w("",!0),v("section",D,[L(f)])])}}}),H=N(P,[["__scopeId","data-v-61bdccea"]]);export{H as default};
//# sourceMappingURL=Main-Css-o6on.js.map
