import{A as n}from"./index-DKWrpYOr.js";import{e as a,b as o,f as r,j as c,H as f,v as d,p as l,g as p,aO as i}from"./jwt-decode.esm-CW-ehmUm.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="0aec6efd-9fc4-4eab-a642-991b916c837c",e._sentryDebugIdIdentifier="sentry-dbid-0aec6efd-9fc4-4eab-a642-991b916c837c")}catch{}})();const u=a({__name:"Steps",props:{stepsInfo:{},isPreview:{type:Boolean}},setup(e){const s=e,t=o(()=>s.stepsInfo?Array(s.stepsInfo.total).fill(null).map(()=>({label:"",description:""})):[]);return(m,b)=>e.stepsInfo?(p(),r("nav",{key:0,class:f(["p-steps",{"full-screen":!e.isPreview}])},[d(l(n),{current:e.stepsInfo.current-1,items:t.value,responsive:!1},null,8,["current","items"])],2)):c("",!0)}}),v=i(u,[["__scopeId","data-v-58fdd395"]]);export{v as S};
//# sourceMappingURL=Steps-r5dlhdUZ.js.map
