import{e as c,b as g,n as r,g as i,p as a,A as b,w as n,v as l,B as d,x as p,y as m,C as u,h as f,j as y,m as B}from"./jwt-decode.esm-CW-ehmUm.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="feb92fae-4031-48e0-8610-29650a48637e",e._sentryDebugIdIdentifier="sentry-dbid-feb92fae-4031-48e0-8610-29650a48637e")}catch{}})();const w=c({__name:"AbstraButton",props:{disabledTooltip:{},tooltip:{},prefixCls:{},type:{},htmlType:{},shape:{},size:{},loading:{type:[Boolean,Object]},disabled:{type:Boolean},ghost:{type:Boolean},block:{type:Boolean},danger:{type:Boolean},icon:{},href:{},target:{},title:{},onClick:{type:[Function,Array]},onMousedown:{type:[Function,Array]}},setup(e){const t=g(()=>o.disabledTooltip&&o.disabled?o.disabledTooltip:o.tooltip),o=e;return(s,k)=>t.value?(i(),r(a(b),{key:0,title:t.value},{default:n(()=>[l(a(d),p(m(s.$props)),{default:n(()=>[l(a(u),{style:{display:"flex","align-items":"center","justify-content":"center",gap:"5px"}},{default:n(()=>[e.loading?y("",!0):f(s.$slots,"default",{key:0})]),_:3})]),_:3},16)]),_:3},8,["title"])):(i(),r(a(d),p(B({key:1},s.$props)),{default:n(()=>[l(a(u),{style:{display:"flex","align-items":"center","justify-content":"center",gap:"5px"}},{default:n(()=>[e.loading?y("",!0):f(s.$slots,"default",{key:0})]),_:3})]),_:3},16))}});export{w as _};
//# sourceMappingURL=AbstraButton.vue_vue_type_script_setup_true_lang-CNvpUmrq.js.map
